@@ -225,8 +225,7 @@ class Commands:
 
         self._reset_buffer()
 
-        # command = b'UPLOAD\r\n'
-        command = b'UPLOAD\r'  # TODO: add b'\n' back into command when bug related to serial buffer is fixed
+        command = b'UPLOAD\r\n'
 
         self.connection.write(command)
         get_ack_reply = self._handle_reply(command=command, terminator=b'ACK\r\n')
