@@ -53,6 +53,12 @@ class Download:
 
         print(f'Progress: [{arrow}{padding}] {int(fraction * 100)}%', end=ending)
 
+    def set_path(self, path):
+
+        self._path = path.rstrip('/') + '/download'
+
+        return self._path
+
     def get_download_parameters(self, fid: int, src: int, sa: int, length: int) -> (bool, dict):
 
         def _get_file_list():
