@@ -184,19 +184,22 @@ class NucleusDriver:
 
     def set_assert_path(self, path: str):
 
-        self.asserts.set_file_path(path=path)
-
-    def read_assert(self) -> bytes:
-
-        return self.asserts.read_assert()
+        return self.asserts.set_file_path(path=path)
 
     def clear_assert(self) -> [bytes]:
 
         return self.asserts.clear_assert()
 
-    def write_encrypted_assert_to_file(self):
+    def assert_download(self):
 
-        self.asserts.write_encrypted_assert_to_file()
+        self.asserts.read_assert()
+
+        status = False
+        if len(self.asserts.assert_encrypted) > 1:
+            self.asserts.write_encrypted_assert_to_file()
+            status = True
+
+        return status
 
     ###########################################
     # Syslog
@@ -204,28 +207,35 @@ class NucleusDriver:
 
     def set_syslog_path(self, path: str):
 
-        self.syslog.set_file_path(path=path)
+        return self.syslog.set_file_path(path=path)
 
     def list_syslog(self):
 
         self.syslog.list_syslog()
 
-    def read_syslog(self):
-
-        return self.syslog.read_syslog()
-
     def clear_syslog(self) -> [bytes]:
 
         return self.syslog.clear_syslog()
 
-    def write_encrypted_syslog_to_file(self):
+    def syslog_download(self):
 
-        self.syslog.write_encrypted_syslog_to_file()
+        self.syslog.read_syslog()
+
+        status = False
+        if len(self.syslog.syslog_encrypted) > 1:
+            self.syslog.write_encrypted_syslog_to_file()
+            status = True
+
+        return status
 
     ###########################################
     # Download
     ###########################################
 
+    def set_download_path(self, path: str):
+
+        return self.download.set_path(path=path)
+
     def download_dvl_data(self, fid=None, sa=None, length=None):
 
         return self.download.download_dvl_data(fid=fid, sa=sa, length=length)
